## code to replicate main results presented in Aykanat et al (2020) Life history genomic regions explain differences in Atlantic salmon marine diet specialization, Journal fo Animal Ecology.

setwd("../codes")
load ( "SC.genoNUM2" )
SC.PHEN3 = read.table ( "SC.PHEN3_15Mar20.txt" , h=T , stringsAsFactors = F , sep = "\t"  ) ## This is data frame from second worksheet of "SC.PHEN3_15Mar20.xlsx"

    str ( SC.genoNUM2 ) ## master genotype data by number
    head ( SC.PHEN3 ) ## mastre phenotype data

    library(lmerTest)
    library(MASS)
    library(glmmTMB)
    library(mgcv)
    library(lme4)

      ## this is the main analytic pipeline associated with total prey weight, binned and anlaysied with glmmTMB.
      {

        ## model to test the genetic basis of total prey weight.
        MS.scl.Wbin.s6v3 = glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp)  ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                            scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |pop.final), ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , 
                                          control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
      
        summary (MS.scl.Wbin.s6v3)
        
        ## model to test the effect of population term. 
        MS.scl.Wbin.s6v3_NONPOP = glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp)  ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                      scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) , ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , 
                                    control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
      
        AIC(MS.scl.Wbin.s6v3) - AIC(MS.scl.Wbin.s6v3_NONPOP)
        anova (MS.scl.Wbin.s6v3 , MS.scl.Wbin.s6v3_NONPOP, test = "LRT")

        ## model to test the genetic basis of total prey weight when only IDs with confidenet population assigenment is included in the model.
        pop.strict.index = which ( SC.PHEN3$pop.pr > 0.7 ) 
        
        MS.scl.Wbin.s6v3.ctrl = glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                       scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |pop.final), ziformula = ~ . , data = SC.PHEN3 [pop.strict.index ,], family= truncated_nbinom2 , 
                                     control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
        
        summary(MS.scl.Wbin.s6v3.ctrl)
        
        ## model to test the significance of population term when only IDs with confidenet population assigenment is included in the model.
        MS.scl.Wbin.s6v3.ctrl_NONPOP = glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                           scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) , ziformula = ~ . , data = SC.PHEN3 [pop.strict.index ,], family= truncated_nbinom2 , 
                                         control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
        
        summary(MS.scl.Wbin.s6v3.ctrl_NONPOP)
        
        AIC(MS.scl.Wbin.s6v3.ctrl) - AIC(MS.scl.Wbin.s6v3.ctrl_NONPOP)
        anova (MS.scl.Wbin.s6v3.ctrl , MS.scl.Wbin.s6v3.ctrl_NONPOP, test = "LRT")

        length(table(SC.PHEN3$pop.final [pop.strict.index]))
        length((SC.PHEN3$pop.final [pop.strict.index]))
        
        ## coefficnet tables for the supplemntary material (Supp. table 2)
        totW.cn.coef = summary (MS.scl.Wbin.s6v3)$coef[[1]]
        totW.zi.coef = summary (MS.scl.Wbin.s6v3)$coef[[2]]
        
        ## coefficnet tables for the supplemntary material (Supp. table 5)
        totW.cn.coef.ctrl = summary (MS.scl.Wbin.s6v3.ctrl)$coef[[1]]
        totW.zi.coef.ctrl = summary (MS.scl.Wbin.s6v3.ctrl)$coef[[2]]

        
        ## below code is to estimate effect size (90%CI) and significnace fo covariates in the model.
        s6.val = as.numeric ( names ( table ( scale (SC.PHEN3$six6) ) ) )
        v3.val = as.numeric ( names ( table ( scale (SC.PHEN3$vgll3) ) ) )

        ## ZERO INFLATION BIT with six6 and vgll3 only
        {        
        # parametric permutations
        summary(MS.scl.Wbin.s6v3)
        
        fixef( MS.scl.Wbin.s6v3 )[[2]]
        vcov( MS.scl.Wbin.s6v3 )[[2]] [ c(1:3,14:22) ,c(1:3,14:22) ] ## variance of coefs
  
        AAA = vcov( MS.scl.Wbin.s6v3 )[[2]]## list [[2]] is the zero inlation model
        BBB = -fixef( MS.scl.Wbin.s6v3 )[[2]] ## ngetaive infromt to make it look like binomial, not ZERO INFLATION!
        
        ## parametric permutations
        MOD1.vcov = AAA
        MOD1.coef = BBB
        MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
        
        
        per1a = model.matrix(MS.scl.Wbin.s6v3)
        per1b = per1a [per1a[,1]==1,]
        per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
        
        per2a = model.matrix(MS.scl.Wbin.s6v3)
        per2b = per2a [per2a[,2]==1,]
        per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
        
        per3a = model.matrix(MS.scl.Wbin.s6v3)
        per3b = per3a [per3a[,3]==1,]
        per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
        
        MVN [ 1:2 , c(1:3,14:22) ]
        table ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) ) # 0.15
        table ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) # 0.030
        table ( apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) # 0.047
  
        table ( MVN [ , 1] > MVN [ , 2] ) ## 0.019
        table ( MVN [ , 2] > MVN [ , 3] ) ## <0.001
        table ( MVN [ , 1] > MVN [ , 3] ) ## <0.001
  
        # odds empty between sea aeg groups
        sort ( exp ( MVN [ , 1]-  MVN [ , 2] ) ) [c(2500,50000,97500)]
        sort ( exp ( MVN [ , 1]-  MVN [ , 3] ) ) [c(2500,50000,97500)]
        sort ( exp ( MVN [ , 2]-  MVN [ , 3] ) ) [c(2500,50000,97500)]
        
        summary (MS.scl.Wbin.s6v3 )
        
        ## odss in increase between LL and EE  in vgll3
              colnames(MVN)[20:22]
              ee.vgll3.food1 = cbind ( MVN [ , 20 ] * v3.val [1]  , MVN [ , 21 ] * v3.val [1]  , MVN [ , 22 ] * v3.val [1] )
              ll.vgll3.food1 = cbind ( MVN [ , 20 ] * v3.val [2]  , MVN [ , 21 ] * v3.val [2]  , MVN [ , 22 ] * v3.val [2] )
              
              odds.v3.1sw = ( exp (ll.vgll3.food1[,1] ) / exp (ee.vgll3.food1[,1] ) )
              odds.v3.2sw = ( exp (ll.vgll3.food1[,2] ) / exp (ee.vgll3.food1[,2] ) )
              odds.v3.3sw = ( exp (ll.vgll3.food1[,3] ) / exp (ee.vgll3.food1[,3] ) )
              
              odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500,50000,97500) ] ## 90%CI
              odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500,50000,97500) ] ## 90%CI
              odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500,50000,97500) ] ## 90%CI
              
              med.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
              CI025.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
              CI975.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]

      ## odss in increase between LL and EE  in six6
              ee.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [1]  , MVN [ , 18 ] * s6.val [1]  , MVN [ , 19 ] * s6.val [1] )
              ll.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [2]  , MVN [ , 18 ] * s6.val [2]  , MVN [ , 19 ] * s6.val [2] )
              
              odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
              odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
              odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
              
              odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500,50000,97500) ]
              odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500,50000,97500) ]
              odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500,50000,97500) ]
              
              med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
              CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
              CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
              
              
                
              ## increase in diet as a function of residual length
  
              ## six6 effect among sea ages
              table ( MVN [ , 17 ] >  MVN [ , 18 ] )
              table ( MVN [ , 17 ] >  MVN [ , 19 ] )
              table ( MVN [ , 18 ] >  MVN [ , 19 ] )
            
              ## vgll3
              table ( MVN [ , 20 ] >  MVN [ , 21 ] )
              table ( MVN [ , 21 ] >  MVN [ , 22 ] )
              table ( MVN [ , 20 ] >  MVN [ , 22 ] )
              
              ## coffiecnet for resL and six6 is negatively correlated
              cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
              cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
              cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
              
              ## MEANS
                            


              ## residual length effect
              length.1SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 1 ] +  MVN [  , 14 ] * XX[i] + MVN [  , 17 ] * s6.val [2] + MVN [  , 20 ]* v3.val [2] ) })
              length.2SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 2 ] +  MVN [  , 15 ] * XX[i] + MVN [  , 18 ] * s6.val [2] + MVN [  , 21 ]* v3.val [2] ) })
              length.3SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 3 ] +  MVN [  , 16 ] * XX[i] + MVN [  , 19 ] * s6.val [2] + MVN [  , 22 ]* v3.val [2] ) })
              
              length.1SW.totW = exp ( length.1SW.totW.pre ) / ( 1 + exp ( length.1SW.totW.pre ) )
              length.2SW.totW = exp ( length.2SW.totW.pre ) / ( 1 + exp ( length.2SW.totW.pre ) )
              length.3SW.totW = exp ( length.3SW.totW.pre ) / ( 1 + exp ( length.3SW.totW.pre ) )
              
              ## median
              length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
              length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
              length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )
              
              ## 95 upper
              length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
              length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
              length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
              
              ## 95 lower
              length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
              length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
              length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )
            
          
    }
        ## ZERO INFLATION BIT  with six6 and vgll3 only      
                
        ## CONDITIONAL BIT with six6 and vgll3 only,
        {
          # parametric permutations
          summary(MS.scl.Wbin.s6v3)
          fixef( MS.scl.Wbin.s6v3 )[[1]]
          vcov( MS.scl.Wbin.s6v3 )[[1]] [ c(1:3,14:22) ,c(1:3,14:22) ] ## variance of coefs

          AAA = vcov( MS.scl.Wbin.s6v3 )[[1]] ## conditioned model
          BBB = fixef( MS.scl.Wbin.s6v3 )[[1]] ## conditioned model
          
          MOD1.vcov = AAA
          MOD1.coef = BBB
          MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )

          per1a = model.matrix(MS.scl.Wbin.s6v3)
          per1b = per1a [per1a[,1]==1,]
          per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
          
          per2a = model.matrix(MS.scl.Wbin.s6v3)
          per2b = per2a [per2a[,2]==1,]
          per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
          
          per3a = model.matrix(MS.scl.Wbin.s6v3)
          per3b = per3a [per3a[,3]==1,]
          per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]

          MVN [ 1:2 , c(1:3,14:22) ]
          table ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) ) # 0.128
          table ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) # 0.023
          table ( apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) # 0.081
          
          ## no resL included here
          table ( apply ( MVN[,c(1:3,17:22)] * per1c[,c(1:3,17:22)] , 1 , sum ) > apply ( MVN[,c(1:3,17:22)] * per2c[,c(1:3,17:22)] , 1 , sum ) ) # 0.103
          table ( apply ( MVN[,c(1:3,17:22)] * per1c[,c(1:3,17:22)] , 1 , sum ) > apply ( MVN[,c(1:3,17:22)] * per3c[,c(1:3,17:22)] , 1 , sum ) ) # 0.009
          table ( apply ( MVN[,c(1:3,17:22)] * per2c[,c(1:3,17:22)] , 1 , sum ) > apply ( MVN[,c(1:3,17:22)] * per3c[,c(1:3,17:22)] , 1 , sum ) ) # 0.032
          
          table ( MVN[,1] < MVN[,2] )
          table ( MVN[,1] < MVN[,3] )
          table ( MVN[,2] < MVN[,3] )
          
          ## six6 parametric sig.
          table ( MVN [,17] > 0 ) # 
          table ( MVN [,18] > 0 ) # 
          table ( MVN [,19] > 0 ) # 
          
          ## six6 parametric sig. between age groups
          table ( MVN [,17] > MVN [,18] ) #
          table ( MVN [,17] > MVN [,19] ) #
          table ( MVN [,18] > MVN [,19] ) #

          ## vgll3 parametric sig.
          table ( MVN [,20] > 0 ) # NA
          table ( MVN [,21] > 0 ) # NA
          table ( MVN [,22] > 0 ) # NA
          
          ## vgll3 parametric sig. between age groups
          table ( MVN [,20] > MVN [,21] )
          table ( MVN [,21] > MVN [,12] )
          table ( MVN [,22] > MVN [,20] )
          

          ## odss in increase between LL and EE  in six6
          ee.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [1]  , MVN [ , 18 ] * s6.val [1]  , MVN [ , 19 ] * s6.val [1] )
          ll.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [2]  , MVN [ , 18 ] * s6.val [2]  , MVN [ , 19 ] * s6.val [2] )
          
          odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
          odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
          odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
          
          odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ] # 90% CI
          odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ] # 90% CI
          odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ] # 90% CI
          
          med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
          CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
          CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
          
          
          ## odss in increase between LL and EE  in vgll3
          colnames(MVN)[20:22]
          ee.vgll3.food1 = cbind ( MVN [ , 20 ] * v3.val [1]  , MVN [ , 21 ] * v3.val [1]  , MVN [ , 22 ] * v3.val [1] )
          ll.vgll3.food1 = cbind ( MVN [ , 20 ] * v3.val [2]  , MVN [ , 21 ] * v3.val [2]  , MVN [ , 22 ] * v3.val [2] )
          
          odds.v3.1sw = ( exp (ll.vgll3.food1[,1] ) / exp (ee.vgll3.food1[,1] ) )
          odds.v3.2sw = ( exp (ll.vgll3.food1[,2] ) / exp (ee.vgll3.food1[,2] ) )
          odds.v3.3sw = ( exp (ll.vgll3.food1[,3] ) / exp (ee.vgll3.food1[,3] ) )
          
          odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500 , 50000 , 97500) ]
          odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500 , 50000 , 97500) ]
          odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]
          
          med.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
          CI025.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
          CI975.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]

          ## coffiecnet for resL and six6 is negatively correlated
          cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
          cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
          cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
          

          ## residual length effect
          length.1SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 1 ] +  MVN [  , 14 ] * XX[i] + MVN [  , 17 ] * s6.val [2] + MVN [  , 20 ]* v3.val [2] ) })
          length.2SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 2 ] +  MVN [  , 15 ] * XX[i] + MVN [  , 18 ] * s6.val [2] + MVN [  , 21 ]* v3.val [2] ) })
          length.3SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 3 ] +  MVN [  , 16 ] * XX[i] + MVN [  , 19 ] * s6.val [2] + MVN [  , 22 ]* v3.val [2] ) })
          
          ## median
          length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
          length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
          length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )

          ## 97.5 upper
          length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
          length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
          length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
          
          ## 97.5 lower
          length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
          length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
          length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )
          
          
              }
        ## CONDITIONAL BIT  with six6 and vgll3 only  

        ### SPLINE PLOTS FPOR DAYS AND LONGITUTITE EFFECT ON YTOTAL WEIGHT (supp. figure 3)
        {
                
                summary(MS.scl.Wbin.s6v3)
                
                fixef( MS.scl.Wbin.s6v3 )[[1]]
                fixef( MS.scl.Wbin.s6v3 )[[2]]
                
                library(MASS)
                ## parametric permutations
                MOD1.vcov = vcov( MS.scl.Wbin.s6v3 )[[1]] ## conditioned model
                MOD1.coef = fixef( MS.scl.Wbin.s6v3 )[[1]] ## conditioned model
                MVN1 = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )## conditioned model
                
                MOD2.vcov = vcov( MS.scl.Wbin.s6v3 )[[2]] ## ZI model
                MOD2.coef = fixef( MS.scl.Wbin.s6v3 )[[2]] ## ZI model
                MVN2 = mvrnorm (100000, mu=MOD2.coef, Sigma = MOD2.vcov ) ## ZI model

                ## splilne plots: 
                summary (MS.scl.Wbin.s6v3)
                
                long_cond_DAT.pre = t ( sapply (1:100000 , function(i) { 
                  ( MVN1 [ i ,4+5 ] * SC.PHEN3 $ sLong1 ) + 
                    ( MVN1 [ i ,5+5 ] * SC.PHEN3 $ sLong2 ) +
                    ( MVN1 [ i ,6+5 ] * SC.PHEN3 $ sLong3 ) +
                    ( MVN1 [ i ,7+5 ] * SC.PHEN3 $ sLong4 ) +
                    ( MVN1 [ i ,8+5 ] * SC.PHEN3 $ sLong5 ) 
                }) )
                

                long_cond_DAT = long_cond_DAT.pre [  , match ( unique(SC.PHEN3$long) , SC.PHEN3$long ) ]
                DAT_long = SC.PHEN3$long [ match ( unique(SC.PHEN3$long) , SC.PHEN3$long ) ]
                
                
                long_cond_DAT_CI = t( apply ( long_cond_DAT , 2 , function(x) { sort ( x [ c ( 5000 , 50000  , 95000 ) ] ) } )  )
                
                plot ( y = long_cond_DAT_CI [,2] , x = DAT_long  , xlab =  "longitude"  , ylab = "Sum(Coefficients(L1-L5)), conditional model" , pch = 20 ,col="gray" , cex=2, ylim =  c(min(long_cond_DAT_CI)  , max(long_cond_DAT_CI) ) )
                for ( i in 1 : length(DAT_long) )  { lines ( y = c (long_cond_DAT_CI [i,1] , long_cond_DAT_CI [i,3] ),  x = c( DAT_long[i] , DAT_long[i] )  , lwd= 2 , col="gray")}
                
                
                long_ZI_DAT.pre = t ( sapply (1:100000 , function(i) { 
                  ( -MVN2 [ i ,4+5 ] * SC.PHEN3 $ sLong1 ) + 
                    ( -MVN2 [ i ,5+5 ] * SC.PHEN3 $ sLong2 ) +
                    ( -MVN2 [ i ,6+5 ] * SC.PHEN3 $ sLong3 ) +
                    ( -MVN2 [ i ,7+5 ] * SC.PHEN3 $ sLong4 ) +
                    ( -MVN2 [ i ,8+5 ] * SC.PHEN3 $ sLong5 ) 
                }) )
                
                long_ZI_DAT = long_ZI_DAT.pre [  , match ( unique(SC.PHEN3$long) , SC.PHEN3$long ) ]
                DAT_long = SC.PHEN3$long [ match ( unique(SC.PHEN3$long) , SC.PHEN3$long ) ]
                
                long_ZI_DAT_CI = t( apply ( long_ZI_DAT , 2 , function(x) { sort ( x [ c ( 5000 , 50000  , 95000 ) ] ) } )  )
                
                plot ( y = long_ZI_DAT_CI [,2] , x = DAT_long  , xlab =  "longitude"  , ylab = "Sum(Coefficients(L1-L5)), ZI model" , pch = 20 ,col="gray" , cex=2, ylim =  c(min(long_ZI_DAT_CI)  , max(long_ZI_DAT_CI) ) )
                for ( i in 1 : length(DAT_long) )  { lines ( y = c (long_ZI_DAT_CI [i,1] , long_ZI_DAT_CI [i,3] ),  x = c( DAT_long[i] , DAT_long[i] )  , lwd= 2 , col="gray")}
                
                
                Days_cond_DAT.pre = t ( sapply (1:100000 , function(i) { 
                  ( MVN1 [ i ,4 ] * SC.PHEN3 $ sDays1 ) + 
                    ( MVN1 [ i ,5 ] * SC.PHEN3 $ sDays2 ) +
                    ( MVN1 [ i ,6 ] * SC.PHEN3 $ sDays3 ) +
                    ( MVN1 [ i ,7 ] * SC.PHEN3 $ sDays4 ) +
                    ( MVN1 [ i ,8 ] * SC.PHEN3 $ sDays5 ) 
                }) )
                
                Days_cond_DAT = Days_cond_DAT.pre [  , match ( unique(SC.PHEN3$DAY) , SC.PHEN3$DAY ) ]
                DAT_Days = SC.PHEN3$DAY [ match ( unique(SC.PHEN3$DAY) , SC.PHEN3$DAY ) ]
                
                Days_cond_DAT_CI = t( apply ( Days_cond_DAT , 2 , function(x) { sort ( x [ c ( 5000 , 50000  , 95000 ) ] ) } )  )
                
                plot ( y = Days_cond_DAT_CI [,2] , x = DAT_Days  , xlab =  "Days (julian calander)"  , ylab = "Sum(Coefficients(D1-D5)), conditional model" , pch = 20 ,col="gray" , cex=2, ylim =  c(min(Days_cond_DAT_CI)  , max(Days_cond_DAT_CI) ) )
                for ( i in 1 : length(DAT_Days) )  { lines ( y = c (Days_cond_DAT_CI [i,1] , Days_cond_DAT_CI [i,3] ),  x = c( DAT_Days[i] , DAT_Days[i] )  , lwd= 2 , col="gray")}
                
                
                Days_ZI_DAT.pre = t ( sapply (1:100000 , function(i) { 
                  ( -MVN2 [ i ,4 ] * SC.PHEN3 $ sDays1 ) + 
                    ( -MVN2 [ i ,5 ] * SC.PHEN3 $ sDays2 ) +
                    ( -MVN2 [ i ,6 ] * SC.PHEN3 $ sDays3 ) +
                    ( -MVN2 [ i ,7 ] * SC.PHEN3 $ sDays4 ) +
                    ( -MVN2 [ i ,8 ] * SC.PHEN3 $ sDays5 ) 
                }) )
                
                Days_ZI_DAT = Days_ZI_DAT.pre [  , match ( unique(SC.PHEN3$DAY) , SC.PHEN3$DAY ) ]
                DAT_Days = SC.PHEN3$DAY [ match ( unique(SC.PHEN3$DAY) , SC.PHEN3$DAY ) ]
                
                Days_ZI_DAT_CI = t( apply ( Days_ZI_DAT , 2 , function(x) { sort ( x [ c ( 5000 , 50000  , 95000 ) ] ) } )  )
                
                plot ( y = Days_ZI_DAT_CI [,2] , x = DAT_Days  , xlab =  "Days (julian calander)"  , ylab = "Sum(Coefficients(L1-L5)), ZI model" , pch = 20 ,col="gray" , cex=2, ylim =  c(min(Days_ZI_DAT_CI)  , max(Days_ZI_DAT_CI) ) )
                for ( i in 1 : length(DAT_Days) )  { lines ( y = c (Days_ZI_DAT_CI [i,1] , Days_ZI_DAT_CI [i,3] ),  x = c( DAT_Days[i] , DAT_Days[i] )  , lwd= 2 , col="gray")}
              }
        ### SPLINE PLOTS FPOR DAYS AND LONGITUTITE EFFECT ON YTOTAL WEIGHT

        ## Other methodological controls to assess rubostness of the model (Supp tables 3,4,6)   
        {                     
          ## model that did not account for residual length or sea age  (Supp. table 4)
                MS.scl.Wbin.s6v3.ctrl.2 = glmmTMB (SCW.totBINS ~  scale (six6) + scale (vgll3.imp) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                                   scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |pop.final), ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , 
                                                 control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
                
                summary(MS.scl.Wbin.s6v3.ctrl.2)
                
                totW.cn.coef.noSA = summary (MS.scl.Wbin.s6v3.ctrl.2)$coef[[1]]
                totW.zi.coef.noSA = summary (MS.scl.Wbin.s6v3.ctrl.2)$coef[[2]]

          ## Modelling log(length) as the response variable (Supp. table 3) 
              MS.scl.Wbin.s6v3.ctrl.3 = lmer ( log(LengthIMP) ~ 0 + Sea.ageF / (  scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                                   scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |pop.final ),
                                               data = SC.PHEN3 [!is.na(SC.PHEN3$LengthIMP) , ]   )
              
              six6.length.relation.29apr19 = summary(MS.scl.Wbin.s6v3.ctrl.3)$coef

          ## Modelling stomach weight when undigeted material is taken into account (Supp. Table 6)
              range(SC.PHEN3$SCW.tot)
              
              bin_index.pre = cbind ( seq(0,400, by=10)[-41] , seq(0,400, by=10)[-1] ) ; bin_index.pre[1,] = c(0.01,10)
              bin_index = rbind ( c(-0.1,0), bin_index.pre )
              bin_index

              SCW.totBINS.unk.inc =   sapply ( 1: length( SC.PHEN3$SCW.tot ) , function(i) {  which ( (bin_index[,1]  < SC.PHEN3$SCW.tot [i] ) & (bin_index[,2]  >= SC.PHEN3$SCW.tot [i] ) == 1)  }) ## raw weight
              SC.PHEN3$SCW.totBINS.unk.inc = SCW.totBINS.unk.inc-1
              
              
              MS.scl.Wbin.s6v3.ctrl4 = glmmTMB (SCW.totBINS.unk.inc ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                            scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |pop.final), ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , 
                                          control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
              
              summary(MS.scl.Wbin.s6v3.ctrl4)
              
              totW.cn.coef.unk.inc = summary (MS.scl.Wbin.s6v3.ctrl4)$coef[[1]]
              totW.zi.coef.unk.inc = summary (MS.scl.Wbin.s6v3.ctrl4)$coef[[2]]

              ### MODELLING SEX EFFECT 
              {  
                
                library(glmmTMB)
                m1.MS.scl.Wbin.s6v3 = glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                                 scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3 [!is.na(sexC),], family= truncated_nbinom2 , 
                                               control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
                
                m2.MS.scl.Wbin.s6v3 = glmmTMB (SCW.totBINS ~  Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + sexC + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                                 scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , 
                                               control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
                
                m3.MS.scl.Wbin.s6v3 = glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) + (sexC) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                                 scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , 
                                               control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) )
                
                
                summary (  m1.MS.scl.Wbin.s6v3 )
                summary (  m2.MS.scl.Wbin.s6v3 )
                summary (  m3.MS.scl.Wbin.s6v3 )  
                
                }
              ### MODELLING SEX EFFECT 
              
              ## RUN TIMING SEA AGE AND SIX6 INTERCATION
              {
                BBB = (SC.PHEN3$DAY -141) / (212-141) #scale it man, wtf!
                RT.m1 = gamm ( BBB ~ Sea.age * six6 + vgll3.imp + sexC + s(long) +   s(popF, bs= "re") , family = binomial, data =  SC.PHEN3 )
                RT.m2 = gamm ( BBB ~ Sea.age + six6 + vgll3.imp + sexC + s(long) +   s(popF, bs= "re") , family = binomial, data =  SC.PHEN3 )
                RT.m3 = gamm ( BBB ~ Sea.age + six6 + vgll3.imp  + s(long) +   s(popF, bs= "re") , family = binomial, data =  SC.PHEN3 )
                
                AIC ( RT.m1$lme )
                AIC ( RT.m2$lme )
                AIC ( RT.m3$lme )
  }  
              ## RUN TIMING SEA AGE AND SIX6 INTERCATION 

              
        }
        ##  Other methodological controls to assess rubostness of the model   
   }     
      ## ENDED  
        
      ## this is the main analytic pipeline associated with total prey number, analysed with glmmTMB.
      {  

        MS.scl.nbin.s6v3 = glmmTMB (SCW.num ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                      scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + (1|pop.final), 
                               ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , control = glmmTMBControl(optCtrl = list(iter.max = 10000, eval.max = 10000), profile = T, collect = FALSE) )
        

        
        totNum.cn.coef = summary (MS.scl.nbin.s6v3)$coef[[1]]
        totNum.zi.coef = summary (MS.scl.nbin.s6v3)$coef[[2]]

        
                
        ## CONDITIONAL BIT with six6 and vgll3.imp only. FIGURE
        {
          
          summary ( MS.scl.nbin.s6v3 )[[6]] [[1]]  

          fixef( MS.scl.nbin.s6v3 )[[1]]
          fixef( MS.scl.nbin.s6v3 )[[2]]
          
          vcov( MS.scl.nbin.s6v3 )[[1]] [ c(1:3,14:22) ,c(1:3,14:22) ] ## variance of coefs
          vcov( MS.scl.nbin.s6v3 )[[2]] [ c(1:3,14:22) ,c(1:3,14:22) ] ## variance of coefs
          
          AAA = vcov( MS.scl.nbin.s6v3 )[[1]] ## conditioned model
          BBB = fixef( MS.scl.nbin.s6v3 )[[1]] ## conditioned model
          
          ## parametric permutations
          MOD1.vcov = AAA
          MOD1.coef = BBB
          MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
          
          
          per1a = model.matrix(MS.scl.nbin.s6v3)
          per1b = per1a [per1a[,1]==1,]
          per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
          
          per2a = model.matrix(MS.scl.nbin.s6v3)
          per2b = per2a [per2a[,2]==1,]
          per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
          
          per3a = model.matrix(MS.scl.nbin.s6v3)
          per3b = per3a [per3a[,3]==1,]
          per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
          
          table ( MVN[,1] < MVN[,2] )
          table ( MVN[,1] < MVN[,3] )
          table ( MVN[,2] < MVN[,3] )
          
          mean ( exp ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) ) )
          mean ( exp ( apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) ) )
          mean ( exp ( apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) )

          ###FIGURES CONDITIONAL BIT

          ### "sea age, average food weight relation" 
          par ( mfrow = c ( 1 , 4 ) )
          
          sw.food1 = cbind ( MVN [ , 1] + MVN [ , 17] * s6.val [2] + MVN [ , 20] * v3.val [2], 
                             MVN [ , 2] + MVN [ , 18] * s6.val [2] + MVN [ , 21] * v3.val [2] , 
                             MVN [ , 3] + MVN [ , 19] * s6.val [2] + MVN [ , 22] * v3.val [2] )
          

          med.weight.per.sea.age  = exp (apply ( sw.food1  , 2 , function(x) { sort(x)[50000] } ) )
          CI250.weight.per.sea.age = exp (apply ( sw.food1  , 2 , function(x) { sort(x)[2500] } ) )
          CI975.weight.per.sea.age = exp (apply ( sw.food1  , 2 , function(x) { sort(x)[97500] } ) )
          
          
          table ( sw.food1[,1] > sw.food1[,2] )
          table ( sw.food1[,1] > sw.food1[,3] )
          table ( sw.food1[,2] > sw.food1[,3] )
          
          
          plot(1, type="n", xlim=c(0.7,3.3), ylim=c(0, 2),  main = "sea age, averege prey number relation" , xlab = "sea age" , 
               ylab = "average prey number (g)" , xaxt = "n")
          
            axis ( 1 , at = 1:3 ,  c("1SW","2SW","3SW")  )
            abline( h=1, lty=2, col = "light green" , lwd=2)
            
            points( x = 1:3 , y = med.weight.per.sea.age , cex = 2, pch = 20, col="light blue" ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI250.weight.per.sea.age[i]  , CI975.weight.per.sea.age[i]  ) , lwd=3, col="light blue" ) }
            
      
          ## odss in increase between LL and EE  in six6
          ee.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [1]  , MVN [ , 18 ] * s6.val [1]  , MVN [ , 19 ] * s6.val [1] )
          ll.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [2]  , MVN [ , 18 ] * s6.val [2]  , MVN [ , 19 ] * s6.val [2] )
          
          odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
          odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
          odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
          
          table ( odds.s6.1sw > 1 )
          table ( odds.s6.2sw > 1 )
          table ( odds.s6.3sw > 1 )
          
          table ( odds.s6.1sw > odds.s6.2sw )
          table ( odds.s6.2sw > odds.s6.3sw )
          table ( odds.s6.1sw > odds.s6.3sw )
          
          
          odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ]
          odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ]
          odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
          
          med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)  [ 2 , ]
          CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
          CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
          
          
          plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0.5 , 2.5),  main = "six6 - prey number relation by sea age" , 
                 xlab = "scaled residual length" , ylab = "rate of increase in (avarege) prey number by allalic substitution at six6" , xaxt = "n")
          abline( h=1, lty=2, col = "light green" , lwd=2)
          axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
          
          points( x = 1:3 , y = med.weight.per.six6 , cex = 2, pch = 20, col="light blue" ) 
          for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.six6[i]  , CI975.weight.per.six6[i]  ) , lwd=3, col="light blue" ) }
          
          
          ## odss in increase between LL and EE  in vgll3.imp
          colnames(MVN)[20:22]
          ee.vgll3.imp.food1 = cbind ( MVN [ , 20 ] * v3.val [1]  , MVN [ , 21 ] * v3.val [1]  , MVN [ , 22 ] * v3.val [1] )
          ll.vgll3.imp.food1 = cbind ( MVN [ , 20 ] * v3.val [2]  , MVN [ , 21 ] * v3.val [2]  , MVN [ , 22 ] * v3.val [2] )
          
          odds.v3.1sw = ( exp (ll.vgll3.imp.food1[,1] ) / exp (ee.vgll3.imp.food1[,1] ) )
          odds.v3.2sw = ( exp (ll.vgll3.imp.food1[,2] ) / exp (ee.vgll3.imp.food1[,2] ) )
          odds.v3.3sw = ( exp (ll.vgll3.imp.food1[,3] ) / exp (ee.vgll3.imp.food1[,3] ) )
          
          table ( odds.v3.2sw >odds.v3.3sw )
          
          odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500 , 50000 , 97500) ]
          odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500 , 50000 , 97500) ]
          odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]
          
          med.weight.per.vgll3.imp = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
          CI025.weight.per.vgll3.imp = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
          CI975.weight.per.vgll3.imp = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]
          
          
          plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0.5 , 2.5),  main = "vgll3.imp - avarege prey number relation by sea age" , 
                 xlab = "scaled residual length" , ylab = "rate of increase in (avarege) prey number by allalic substitution at vgll3.imp" , xaxt = "n")
          abline( h=1, lty=2, col = "light green" , lwd=2)
          axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
          
          points( x = 1:3 , y = med.weight.per.vgll3.imp , cex = 2, pch = 20, col="light blue" ) 
          for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.vgll3.imp[i]  , CI975.weight.per.vgll3.imp[i]  ) , lwd=3, col="light blue" ) }
          
          
          ## increase in diet as a function of residual length
          
          
          
          colnames(MVN)
          ## six6 effect among sea ages
          table ( MVN [ , 17 ] >  MVN [ , 18 ] ) ## 
          table ( MVN [ , 17 ] >  MVN [ , 19 ] ) ## 
          table ( MVN [ , 18 ] >  MVN [ , 19 ] ) ## 
          
          table ( MVN [ , 20 ] >  MVN [ , 21 ] ) ## 
          table ( MVN [ , 21 ] >  MVN [ , 22 ] ) ## 
          table ( MVN [ , 20 ] >  MVN [ , 22 ] ) ## 
          
          ## coffiecnet for resL2 and six6 is negatively correlated
          cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
          cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
          cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
          
          ## MEANS
          XX= seq ( -1.6 , 1.6 , by = 0.2)
          head(MVN)

          ## residual length effect
          length.1SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 1 ] +  MVN [  , 14 ] * XX[i] + MVN [  , 17 ] * s6.val [2] + MVN [  , 20 ]* v3.val [2] ) })
          length.2SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 2 ] +  MVN [  , 15 ] * XX[i] + MVN [  , 18 ] * s6.val [2] + MVN [  , 21 ]* v3.val [2] ) })
          length.3SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 3 ] +  MVN [  , 16 ] * XX[i] + MVN [  , 19 ] * s6.val [2] + MVN [  , 22 ]* v3.val [2] ) })
          
          ## median
          length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
          length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
          length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )
          
          ## 95 upper
          length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
          length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
          length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
          
          ## 95 lower
          length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
          length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
          length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )

          
        }
        ## CONDITIONAL BIT  with six6 and vgll3.imp only

       
        
 }
      ## ENDED    
      
      ## this is the main analytic pipeline associated with average prey weight, binned and anlaysied with glmmTMB.
      {
          MS.scl.aveW.bin.s6v3 = glmmTMB (SCW.aveBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + scale (vgll3.imp) ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + (1|pop.final), 
                                     ziformula = ~ . , data = SC.PHEN3, family= truncated_nbinom2 , control = glmmTMBControl(optCtrl = list(iter.max = 10000, eval.max = 10000), profile = T, collect = FALSE) )
      
          
          aveW.cn.coef = summary (MS.scl.aveW.bin.s6v3)$coef[[1]]
          aveW.zi.coef = summary (MS.scl.aveW.bin.s6v3)$coef[[2]]


          ## CONDITIONAL BIT with six6 and vgll3.imp only. FIGURE
          {
            
            summary ( MS.scl.aveW.bin.s6v3 )

      
            fixef( MS.scl.aveW.bin.s6v3 )[[1]]
            fixef( MS.scl.aveW.bin.s6v3 )[[2]]
            
            vcov( MS.scl.aveW.bin.s6v3 )[[1]] [ c(1:3,14:22) ,c(1:3,14:22) ] ## variance of coefs
            vcov( MS.scl.aveW.bin.s6v3 )[[2]] [ c(1:3,14:22) ,c(1:3,14:22) ] ## variance of coefs
            
            AAA = vcov( MS.scl.aveW.bin.s6v3 )[[1]] ## conditioned model
            BBB = fixef( MS.scl.aveW.bin.s6v3 )[[1]] ## conditioned model
            
            ## parametric permutations
            MOD1.vcov = AAA
            MOD1.coef = BBB
            MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
            
            
            per1a = model.matrix(MS.scl.aveW.bin.s6v3)
            per1b = per1a [per1a[,1]==1,]
            per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
            
            per2a = model.matrix(MS.scl.aveW.bin.s6v3)
            per2b = per2a [per2a[,2]==1,]
            per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
            
            per3a = model.matrix(MS.scl.aveW.bin.s6v3)
            per3b = per3a [per3a[,3]==1,]
            per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
      
            MVN [ 1:2 , c(1:3,14:22) ]
            table ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) ) # 0.128
            table ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) # 0.023
            table ( apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) > apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) # 0.081
            
            ## no resL2 included here
            table ( apply ( MVN[,c(1:3,17:22)] * per1c[,c(1:3,17:22)] , 1 , sum ) > apply ( MVN[,c(1:3,17:22)] * per2c[,c(1:3,17:22)] , 1 , sum ) ) # 0.103
            table ( apply ( MVN[,c(1:3,17:22)] * per1c[,c(1:3,17:22)] , 1 , sum ) > apply ( MVN[,c(1:3,17:22)] * per3c[,c(1:3,17:22)] , 1 , sum ) ) # 0.009
            table ( apply ( MVN[,c(1:3,17:22)] * per2c[,c(1:3,17:22)] , 1 , sum ) > apply ( MVN[,c(1:3,17:22)] * per3c[,c(1:3,17:22)] , 1 , sum ) ) # 0.032
            
            table ( MVN[,1] < MVN[,2] )
            table ( MVN[,1] < MVN[,3] )
            table ( MVN[,2] < MVN[,3] )
            
            mean ( exp ( apply ( MVN[,c(1:3,14:22)] * per1c[,c(1:3,14:22)] , 1 , sum ) ) )
                   mean ( exp ( apply ( MVN[,c(1:3,14:22)] * per2c[,c(1:3,14:22)] , 1 , sum ) ) )
                          mean ( exp ( apply ( MVN[,c(1:3,14:22)] * per3c[,c(1:3,14:22)] , 1 , sum ) ) )
            
            
            
            ###FIGURES CONDITIONAL BIT
      
            
            ### "sea age, average food weight relation" 
            par ( mfrow = c ( 1 , 4 ) )
            
            sw.food1 = cbind ( MVN [ , 1] + MVN [ , 17] * s6.val [2] + MVN [ , 20] * v3.val [2], 
                               MVN [ , 2] + MVN [ , 18] * s6.val [2] + MVN [ , 21] * v3.val [2] , 
                               MVN [ , 3] + MVN [ , 19] * s6.val [2] + MVN [ , 22] * v3.val [2] )
            
            
            med.weight.per.sea.age  = exp (apply ( sw.food1  , 2 , function(x) { sort(x)[50000] } ) )
            CI025.weight.per.sea.age = exp (apply ( sw.food1  , 2 , function(x) { sort(x)[2500] } ) )
            CI975.weight.per.sea.age = exp (apply ( sw.food1  , 2 , function(x) { sort(x)[97500] } ) )

            #5*med.weight.per.sea.age (5 gr per index unit)
            #5*CI025.weight.per.sea.age
            #5*CI975.weight.per.sea.age
            
            plot(1, type="n", xlim=c(0.7,3.3), ylim=c(0, 8),  main = "sea age, averege prey weight relation" , xlab = "sea age" , 
                 ylab = "average prey amount (g)" , yaxt = "n" , xaxt = "n")
            
            axis ( 1 , at = 1:3 ,  c("1SW","2SW","3SW")  )
            
            points( x = 1:3 , y = med.weight.per.sea.age , cex = 2, pch = 20, col="light blue" ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI10.weight.per.sea.age[i]  , CI90.weight.per.sea.age[i]  ) , lwd=3, col="light blue" ) }
            
            axis ( 2 , at = seq ( 0 , 10 , by = 2 ) , bin_index.figure[,2] [ bin_index.figure[,1] %in%  seq ( 0 , 10 , by = 2 ) ] )
            legend ( x=-1.5, y=10, lwd =3 , col = c("light green", "orange" , "light blue") , pch=20, legend = c("1SW","2SW","3SW") , bty = "n" , cex=1.7)
            
            ## odss in increase between LL and EE  in six6
            ee.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [1]  , MVN [ , 18 ] * s6.val [1]  , MVN [ , 19 ] * s6.val [1] )
            ll.six6.food1 = cbind ( MVN [ , 17 ] * s6.val [2]  , MVN [ , 18 ] * s6.val [2]  , MVN [ , 19 ] * s6.val [2] )
            
            odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
            odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
            odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
            
            odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            table (odds.s6.1sw > odds.s6.2sw )
            table (odds.s6.1sw > odds.s6.3sw )
            table (odds.s6.2sw > odds.s6.3sw )
            
            med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
            CI10.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
            CI90.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0.5 , 3.5),  main = "six6 (avarege) prey weight relation by sea age" , 
                   xlab = "scaled residual length" , ylab = "rate of increase in (avarege) prey weight by allalic substitution at six6" , xaxt = "n")
            abline( h=1, lty=2, col = "light green" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.six6 , cex = 2, pch = 20, col="light blue" ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI10.weight.per.six6[i]  , CI90.weight.per.six6[i]  ) , lwd=3, col="light blue" ) }
            
            
            ## odss in increase between LL and EE  in vgll3.imp
            colnames(MVN)[20:22]
            ee.vgll3.imp.food1 = cbind ( MVN [ , 20 ] * v3.val [1]  , MVN [ , 21 ] * v3.val [1]  , MVN [ , 22 ] * v3.val [1] )
            ll.vgll3.imp.food1 = cbind ( MVN [ , 20 ] * v3.val [2]  , MVN [ , 21 ] * v3.val [2]  , MVN [ , 22 ] * v3.val [2] )
            
            odds.v3.1sw = ( exp (ll.vgll3.imp.food1[,1] ) / exp (ee.vgll3.imp.food1[,1] ) )
            odds.v3.2sw = ( exp (ll.vgll3.imp.food1[,2] ) / exp (ee.vgll3.imp.food1[,2] ) )
            odds.v3.3sw = ( exp (ll.vgll3.imp.food1[,3] ) / exp (ee.vgll3.imp.food1[,3] ) )
            
            odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 5000 , 50000 , 95000) ]
            odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 5000 , 50000 , 95000) ]
            odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 5000 , 50000 , 95000) ]
            
            med.weight.per.vgll3.imp = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
            CI10.weight.per.vgll3.imp = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
            CI90.weight.per.vgll3.imp = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0.5 , 3.5),  main = "six6 (avarege) prey weight relation by sea age" , 
                   xlab = "scaled residual length" , ylab = "rate of increase in (avarege) prey weight by allalic substitution at six6" , xaxt = "n")
            abline( h=1, lty=2, col = "light green" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.vgll3.imp , cex = 2, pch = 20, col="light blue" ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI10.weight.per.vgll3.imp[i]  , CI90.weight.per.vgll3.imp[i]  ) , lwd=3, col="light blue" ) }
            
            
            ## six6 effect among sea ages
            table ( MVN [ , 17 ] >  MVN [ , 18 ] ) ## 
            table ( MVN [ , 17 ] >  MVN [ , 19 ] ) ## 
            table ( MVN [ , 18 ] >  MVN [ , 19 ] ) ## 
            
            table ( MVN [ , 20 ] >  MVN [ , 21 ] ) ## 
            table ( MVN [ , 21 ] >  MVN [ , 22 ] ) ## 
            table ( MVN [ , 20 ] >  MVN [ , 22 ] ) ## 
            
            ## coffiecnet for resL2 and six6 is negatively correlated
            cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
            cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
            cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
            
            ## MEANS

            ## residual length effect
            length.1SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 1 ] +  MVN [  , 14 ] * XX[i] + MVN [  , 17 ] * s6.val [2] + MVN [  , 20 ]* v3.val [2] ) })
            length.2SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 2 ] +  MVN [  , 15 ] * XX[i] + MVN [  , 18 ] * s6.val [2] + MVN [  , 21 ]* v3.val [2] ) })
            length.3SW.totW = sapply ( 1: length(XX) , function(i) { exp ( MVN [  , 3 ] +  MVN [  , 16 ] * XX[i] + MVN [  , 19 ] * s6.val [2] + MVN [  , 22 ]* v3.val [2] ) })
            
            ## median
            length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )
            
            ## 95 upper
            length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[5000] }  )
            length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[5000] }  )
            length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[5000] }  )
            
            ## 95 lower
            length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[95000] }  )
            length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[95000] }  )
            length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[95000] }  )
            

            
            
          }
          ## CONDITIONAL BIT  with six6 and vgll3.imp only

 }  
      ## ENDED  

## individual level association with prey

  ## prey species weight proprtion 
  {

    
    
          SC.PHEN_bok = SC.PHEN3 [ (SC.PHEN3$SCW.tot.ex) != 0 ,  ]

          ## proportion of a species compared to total  
          
           SC.PHEN_bok$SCW.eel.PR =  SC.PHEN_bok$SCW.eel / ( SC.PHEN_bok$SCW.eel + SC.PHEN_bok$SCW.cap + SC.PHEN_bok$SCW.her + SC.PHEN_bok$SCW.had ) 
           SC.PHEN_bok$SCW.cap.PR =  SC.PHEN_bok$SCW.cap / ( SC.PHEN_bok$SCW.eel + SC.PHEN_bok$SCW.cap + SC.PHEN_bok$SCW.her + SC.PHEN_bok$SCW.had ) 
           SC.PHEN_bok$SCW.her.PR =  SC.PHEN_bok$SCW.her / ( SC.PHEN_bok$SCW.eel + SC.PHEN_bok$SCW.cap + SC.PHEN_bok$SCW.her + SC.PHEN_bok$SCW.had ) 
           SC.PHEN_bok$SCW.had.PR =  SC.PHEN_bok$SCW.had / ( SC.PHEN_bok$SCW.eel + SC.PHEN_bok$SCW.cap + SC.PHEN_bok$SCW.her + SC.PHEN_bok$SCW.had ) 

          SC.PHEN_bok$popF = as.factor(SC.PHEN_bok$pop.final)
          
          wm.PA.eel.s6v3.A  =  ( gamm ( SCW.eel.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale(vgll3.imp) ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok ) )
          wm.PA.cap.s6v3.A  =  ( gamm ( SCW.cap.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale(vgll3.imp) ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok ) )
          wm.PA.her.s6v3.A  =  ( gamm ( SCW.her.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale(vgll3.imp) ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok ) )
          wm.PA.had.s6v3.A  =  ( gamm ( SCW.had.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale(vgll3.imp) ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok ) )
          wm.PA.had.s6v3.A  =  ( gam ( SCW.had.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale(vgll3.imp) ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok ) )

          ## supp. table 9
          summary  ( wm.PA.eel.s6v3.A$gam )
          summary  ( wm.PA.cap.s6v3.A$gam )
          summary  ( wm.PA.her.s6v3.A$gam )
          summary  ( wm.PA.had.s6v3.A$lme ) # GAM did not converge


          ## EEL figures six6 and vgll3 only
          {        
            summary(wm.PA.eel.s6v3.A$gam)
            
            vcov ( wm.PA.eel.s6v3.A$gam )
            coef ( wm.PA.eel.s6v3.A$gam )
            
            
            AAA = vcov ( wm.PA.eel.s6v3.A$gam )## list [[2]] is the zero inlation model
            BBB = coef ( wm.PA.eel.s6v3.A$gam ) ## ngetaive infromt to make it look like binomial, not ZERO INFLATION!
            
            library(MASS)

            ## parametric permutations
            MOD1.vcov = AAA
            MOD1.coef = BBB
            MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
            
            per1a = model.matrix(wm.PA.eel.s6v3.A$gam)
            per1b = per1a [per1a[,1]==1,]
            per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
            
            per2a = model.matrix(wm.PA.eel.s6v3.A$gam)
            per2b = per2a [per2a[,2]==1,]
            per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
            
            per3a = model.matrix(wm.PA.eel.s6v3.A$gam)
            per3b = per3a [per3a[,3]==1,]
            per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
            
            ### "sea age, average food weight relation" 

            head(MVN)
            
            ### "sea age, average food weight relation" 
            par ( mfrow = c ( 1 , 4 ) )
            
            sw.food1 = cbind ( MVN [ , 1] + MVN [ , 7] * s6.val [2] + MVN [ , 10] * v3.val [2], 
                               MVN [ , 2] + MVN [ , 8] * s6.val [2] + MVN [ , 11] * v3.val [2] , 
                               MVN [ , 3] + MVN [ , 9] * s6.val [2] + MVN [ , 12] * v3.val [2] )
            
            
            prob.full.per.sea.age      = exp ( sw.food1[,] ) / (1 + exp (sw.food1[,]) )
            med.prob.full.per.sea.age  =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[50000] } ) )
            CI025.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[2500] } ) )
            CI975.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[97500] } ) )
            
            
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,2] ) ## p=0.123
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,3] ) # p < 0.001
            table ( prob.full.per.sea.age[,2] > prob.full.per.sea.age[,3] ) # p < 0.001
            
            plot(1, type="n", xlim=c(0.7,3.3), ylim=c(0 , 0.5),  main = "probablity of eel in the stomach per sea age" , xlab = "sea age" , 
                 ylab = "probablity of eel in the stomach" ,  xaxt = "n")
            
            axis ( 1 , at = 1:3 ,  c("1SW","2SW","3SW")  )
            
            points( x = 1:3 , y = med.prob.full.per.sea.age , cex = 2, pch = 20, col=c("light green","orange","light blue") ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.prob.full.per.sea.age[i]  , CI975.prob.full.per.sea.age[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            legend ( x=1, y=0.5, lwd =3 , col = c("light green", "orange" , "light blue") , pch=20, legend = c("1SW","2SW","3SW") , bty = "n" , cex=1.7)
            
            ## odss in increase between LL and EE  in six6
            colnames(MVN)[7:9]
            ee.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [1]  , MVN [ , 8 ] * s6.val [1]  , MVN [ , 9 ] * s6.val [1] )
            ll.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [2]  , MVN [ , 8 ] * s6.val [2]  , MVN [ , 9 ] * s6.val [2] )
            
            odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
            odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
            odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
            
            odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
            CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
            CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
            
            table ( odds.s6.1sw > odds.s6.2sw ) # p > 0.05
            table ( odds.s6.1sw > odds.s6.3sw ) # p > 0.05
            table ( odds.s6.3sw > odds.s6.2sw ) # p > 0.05
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 2),  main = "Odds of capleine in the stomach by six6 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of capleine in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light gray" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.six6 , cex = 2, pch = 20, col= c("light green","orange","light blue")  ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.six6[i]  , CI975.weight.per.six6[i]  ) , lwd=3, col=c("light green","orange","light blue")[i]) }
            
            
            ## odss in increase between LL and EE  in vgll3
            colnames(MVN)[10:12]
            ee.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [1]  , MVN [ , 11 ] * v3.val [1]  , MVN [ , 12 ] * v3.val [1] )
            ll.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [2]  , MVN [ , 11 ] * v3.val [2]  , MVN [ , 12 ] * v3.val [2] )
            
            odds.v3.1sw = ( exp (ll.vgll3.food1[,1] ) / exp (ee.vgll3.food1[,1] ) )
            odds.v3.2sw = ( exp (ll.vgll3.food1[,2] ) / exp (ee.vgll3.food1[,2] ) )
            odds.v3.3sw = ( exp (ll.vgll3.food1[,3] ) / exp (ee.vgll3.food1[,3] ) )
            
            odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
            CI025.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
            CI975.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 2),  main = "Odds of capleine in the stomach by vgll3 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of capleine in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light green" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.vgll3 , cex = 2, pch = 20, col=c("light green","orange","light blue")) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.vgll3[i]  , CI975.weight.per.vgll3[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            
            table ( odds.v3.1sw > odds.v3.2sw ) # 
            table ( odds.v3.1sw > odds.v3.3sw ) # 
            table ( odds.v3.3sw > odds.v3.2sw ) # 
            
            ## increase in diet as a function of residual length
            
            
            
            
            ## six6 effect among sea ages
            table ( MVN [ , 17 ] >  MVN [ , 18 ] ) ## 
            table ( MVN [ , 17 ] >  MVN [ , 19 ] ) ## 
            table ( MVN [ , 18 ] >  MVN [ , 19 ] ) ## 
            
            table ( MVN [ , 20 ] >  MVN [ , 21 ] ) ## 
            table ( MVN [ , 21 ] >  MVN [ , 22 ] ) ## 
            table ( MVN [ , 20 ] >  MVN [ , 22 ] ) ## 
            
            ## coffiecnet for resL and six6 is negatively correlated
            cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
            cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
            cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
            
            ## MEANS
            
            XX= seq ( -1.6 , 1.6 , by = 0.05)
            
            i=1
            
            colnames(MVN)[1:12]
            
            ## residual length effect
            length.1SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 1 ] +  MVN [  , 4 ] * XX[i] + MVN [  , 7 ] * s6.val [2] + MVN [  , 10 ]* v3.val [2] ) })
            length.2SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 2 ] +  MVN [  , 5 ] * XX[i] + MVN [  , 8 ] * s6.val [2] + MVN [  , 11 ]* v3.val [2] ) })
            length.3SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 3 ] +  MVN [  , 6 ] * XX[i] + MVN [  , 9 ] * s6.val [2] + MVN [  , 12 ]* v3.val [2] ) })
            
            length.1SW.totW = exp ( length.1SW.totW.pre ) / ( 1 + exp ( length.1SW.totW.pre ) )
            length.2SW.totW = exp ( length.2SW.totW.pre ) / ( 1 + exp ( length.2SW.totW.pre ) )
            length.3SW.totW = exp ( length.3SW.totW.pre ) / ( 1 + exp ( length.3SW.totW.pre ) )
            
            ## median
            length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )
            
            ## 95 upper
            length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
            
            ## 95 lower
            length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )
            
            
          }
          ## eel probablaities      

          ## capelin figures six6 and vgll3 only
          {        
            summary(wm.PA.cap.s6v3.A$gam)
            
            vcov ( wm.PA.cap.s6v3.A$gam )
            coef ( wm.PA.cap.s6v3.A$gam )
            
            
            AAA = vcov ( wm.PA.cap.s6v3.A$gam )## list [[2]] is the zero inlation model
            BBB = coef ( wm.PA.cap.s6v3.A$gam ) ## ngetaive infromt to make it look like binomial, not ZERO INFLATION!
            
            library(MASS)
            #AA1  =model.matrix (ss.PA1.six6.m1$gam)
            
            ## parametric permutations
            MOD1.vcov = AAA
            MOD1.coef = BBB
            MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
            
            per1a = model.matrix(wm.PA.cap.s6v3.A$gam)
            per1b = per1a [per1a[,1]==1,]
            per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
            
            per2a = model.matrix(wm.PA.cap.s6v3.A$gam)
            per2b = per2a [per2a[,2]==1,]
            per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
            
            per3a = model.matrix(wm.PA.cap.s6v3.A$gam)
            per3b = per3a [per3a[,3]==1,]
            per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
            
            ### "sea age, average food weight relation" 
            
            head(MVN)
            
            ### "sea age, average food weight relation" 
            
            #par ( mfrow = c ( 1 , 4 ) )
            
            sw.food1 = cbind ( MVN [ , 1] + MVN [ , 7] * s6.val [2] + MVN [ , 10] * v3.val [2], 
                               MVN [ , 2] + MVN [ , 8] * s6.val [2] + MVN [ , 11] * v3.val [2] , 
                               MVN [ , 3] + MVN [ , 9] * s6.val [2] + MVN [ , 12] * v3.val [2] )
            
            
            prob.full.per.sea.age      = exp ( sw.food1[,] ) / (1 + exp (sw.food1[,]) )
            med.prob.full.per.sea.age  =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[50000] } ) )
            CI025.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[2500] } ) )
            CI975.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[97500] } ) )
            
            plot(1, type="n", xlim=c(0.7,3.3), ylim=c(0 , 0.5),  main = "probablity of capelin in the stomach per sea age" , xlab = "sea age" , 
                 ylab = "probablity of capelin in the stomach" ,  xaxt = "n")
            
            axis ( 1 , at = 1:3 ,  c("1SW","2SW","3SW")  )
            
            points( x = 1:3 , y = med.prob.full.per.sea.age , cex = 2, pch = 20, col=c("light green","orange","light blue") ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.prob.full.per.sea.age[i]  , CI975.prob.full.per.sea.age[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            legend ( x=1, y=0.5, lwd =3 , col = c("light green", "orange" , "light blue") , pch=20, legend = c("1SW","2SW","3SW") , bty = "n" , cex=1.7)
            
            
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,2] ) ## p=0.041
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,3] ) # p < 0.001
            table ( prob.full.per.sea.age[,2] > prob.full.per.sea.age[,3] ) # p < 0.001
            
            
            ## odss in increase between LL and EE  in six6
            colnames(MVN)[7:9]
            ee.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [1]  , MVN [ , 8 ] * s6.val [1]  , MVN [ , 9 ] * s6.val [1] )
            ll.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [2]  , MVN [ , 8 ] * s6.val [2]  , MVN [ , 9 ] * s6.val [2] )
            
            odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
            odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
            odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
            
            odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
            CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
            CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 2),  main = "Odds of capleine in the stomach by six6 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of capleine in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light gray" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.six6 , cex = 2, pch = 20, col= c("light green","orange","light blue")  ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.six6[i]  , CI975.weight.per.six6[i]  ) , lwd=3, col=c("light green","orange","light blue")[i]) }
            
            table ( odds.s6.1sw > odds.s6.2sw ) # 
            table ( odds.s6.1sw > odds.s6.3sw ) # 
            table ( odds.s6.3sw > odds.s6.2sw ) # 
            
            sort ( odds.s6.1sw / odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            sort ( odds.s6.2sw / odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            ## odss in increase between LL and EE  in vgll3
            colnames(MVN)[10:12]
            ee.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [1]  , MVN [ , 11 ] * v3.val [1]  , MVN [ , 12 ] * v3.val [1] )
            ll.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [2]  , MVN [ , 11 ] * v3.val [2]  , MVN [ , 12 ] * v3.val [2] )
            
            odds.v3.1sw = ( exp (ll.vgll3.food1[,1] ) / exp (ee.vgll3.food1[,1] ) )
            odds.v3.2sw = ( exp (ll.vgll3.food1[,2] ) / exp (ee.vgll3.food1[,2] ) )
            odds.v3.3sw = ( exp (ll.vgll3.food1[,3] ) / exp (ee.vgll3.food1[,3] ) )
            
            odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
            CI025.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
            CI975.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 2),  main = "Odds of capleine in the stomach by vgll3 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of capleine in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light green" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.vgll3 , cex = 2, pch = 20, col=c("light green","orange","light blue")) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.vgll3[i]  , CI975.weight.per.vgll3[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            table ( odds.s6.1sw > odds.s6.2sw ) 
            table ( odds.s6.1sw > odds.s6.3sw ) 
            table ( odds.s6.3sw > odds.s6.2sw ) 
            
            table ( odds.v3.1sw > odds.v3.2sw ) 
            table ( odds.v3.1sw > odds.v3.3sw ) 
            table ( odds.v3.3sw > odds.v3.2sw ) 
            
            sort ( odds.v3.1sw / odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]

            ## six6 effect among sea ages
            table ( MVN [ , 17 ] >  MVN [ , 18 ] )
            table ( MVN [ , 17 ] >  MVN [ , 19 ] )
            table ( MVN [ , 18 ] >  MVN [ , 19 ] )
            
            table ( MVN [ , 20 ] >  MVN [ , 21 ] )
            table ( MVN [ , 21 ] >  MVN [ , 22 ] )
            table ( MVN [ , 20 ] >  MVN [ , 22 ] )
          
            ## coffiecnet for resL and six6 is negatively correlated
            cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
            cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
            cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
            
            ## MEANS
            
            XX= seq ( -1.6 , 1.6 , by = 0.05)
            
            i=1
            
            colnames(MVN)[1:12]
            
            ## residual length effect
            length.1SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 1 ] +  MVN [  , 4 ] * XX[i] + MVN [  , 7 ] * s6.val [2] + MVN [  , 10 ]* v3.val [2] ) })
            length.2SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 2 ] +  MVN [  , 5 ] * XX[i] + MVN [  , 8 ] * s6.val [2] + MVN [  , 11 ]* v3.val [2] ) })
            length.3SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 3 ] +  MVN [  , 6 ] * XX[i] + MVN [  , 9 ] * s6.val [2] + MVN [  , 12 ]* v3.val [2] ) })
            
            length.1SW.totW = exp ( length.1SW.totW.pre ) / ( 1 + exp ( length.1SW.totW.pre ) )
            length.2SW.totW = exp ( length.2SW.totW.pre ) / ( 1 + exp ( length.2SW.totW.pre ) )
            length.3SW.totW = exp ( length.3SW.totW.pre ) / ( 1 + exp ( length.3SW.totW.pre ) )
            
            ## median
            length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )

            ## 95 upper
            length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
            
            ## 95 lower
            length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )
          }
          ## capelin probablaities        
          
          ## herring figures six6 and vgll3 only
          {        
            summary(wm.PA.her.s6v3.A$gam)
            
            vcov ( wm.PA.her.s6v3.A$gam )
            coef ( wm.PA.her.s6v3.A$gam )
            
            
            AAA = vcov ( wm.PA.her.s6v3.A$gam )## list [[2]] is the zero inlation model
            BBB = coef ( wm.PA.her.s6v3.A$gam ) ## ngetaive infromt to make it look like binomial, not ZERO INFLATION!
            
            library(MASS)
            #AA1  =model.matrix (ss.PA1.six6.m1$gam)
            
            ## parametric permutations
            MOD1.vcov = AAA
            MOD1.coef = BBB
            MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
            
            per1a = model.matrix(wm.PA.her.s6v3.A$gam)
            per1b = per1a [per1a[,1]==1,]
            per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
            
            per2a = model.matrix(wm.PA.her.s6v3.A$gam)
            per2b = per2a [per2a[,2]==1,]
            per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
            
            per3a = model.matrix(wm.PA.her.s6v3.A$gam)
            per3b = per3a [per3a[,3]==1,]
            per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
            
            ### "sea age, average food weight relation" 
            
            head(MVN)
            
            ### "sea age, average food weight relation" 
            par ( mfrow = c ( 1 , 4 ) )
            
            sw.food1 = cbind ( MVN [ , 1] + MVN [ , 7] * s6.val [2] + MVN [ , 10] * v3.val [2], 
                               MVN [ , 2] + MVN [ , 8] * s6.val [2] + MVN [ , 11] * v3.val [2] , 
                               MVN [ , 3] + MVN [ , 9] * s6.val [2] + MVN [ , 12] * v3.val [2] )
            
            
            prob.full.per.sea.age      = exp ( sw.food1[,] ) / (1 + exp (sw.food1[,]) )
            med.prob.full.per.sea.age  =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[50000] } ) )
            CI025.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[2500] } ) )
            CI975.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[97500] } ) )
            
            plot(1, type="n", xlim=c(0.7,3.3), ylim=c(0 , 1),  main = "probablity of herring in the stomach per sea age" , xlab = "sea age" , 
                 ylab = "probablity of herring in the stomach" ,  xaxt = "n")
            
            axis ( 1 , at = 1:3 ,  c("1SW","2SW","3SW")  )
            
            points( x = 1:3 , y = med.prob.full.per.sea.age , cex = 2, pch = 20, col=c("light green","orange","light blue") ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.prob.full.per.sea.age[i]  , CI975.prob.full.per.sea.age[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            legend ( x = 1, y=1, lwd =3 , col = c("light green", "orange" , "light blue") , pch=20, legend = c("1SW","2SW","3SW") , bty = "n" , cex=1.7)
            
            
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,2] ) ## p=0.007
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,3] ) # p < 0.001
            table ( prob.full.per.sea.age[,2] > prob.full.per.sea.age[,3] ) # p < 0.001
            
            ## odss in increase between LL and EE  in six6
            colnames(MVN)[7:9]
            ee.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [1]  , MVN [ , 8 ] * s6.val [1]  , MVN [ , 9 ] * s6.val [1] )
            ll.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [2]  , MVN [ , 8 ] * s6.val [2]  , MVN [ , 9 ] * s6.val [2] )
            
            odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
            odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
            odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
            
            odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
            CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
            CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 2),  main = "Odds of capleine in the stomach by six6 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of capleine in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light gray" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.six6 , cex = 2, pch = 20, col= c("light green","orange","light blue")  ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.six6[i]  , CI975.weight.per.six6[i]  ) , lwd=3, col=c("light green","orange","light blue")[i]) }
            
            
            ## odss in increase between LL and EE  in vgll3
            colnames(MVN)[10:12]
            ee.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [1]  , MVN [ , 11 ] * v3.val [1]  , MVN [ , 12 ] * v3.val [1] )
            ll.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [2]  , MVN [ , 11 ] * v3.val [2]  , MVN [ , 12 ] * v3.val [2] )
            
            odds.v3.1sw = ( exp (ll.vgll3.food1[,1] ) / exp (ee.vgll3.food1[,1] ) )
            odds.v3.2sw = ( exp (ll.vgll3.food1[,2] ) / exp (ee.vgll3.food1[,2] ) )
            odds.v3.3sw = ( exp (ll.vgll3.food1[,3] ) / exp (ee.vgll3.food1[,3] ) )
            
            odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
            CI025.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
            CI975.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 2),  main = "Odds of capleine in the stomach by vgll3 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of capleine in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light green" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.vgll3 , cex = 2, pch = 20, col=c("light green","orange","light blue")) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.vgll3[i]  , CI975.weight.per.vgll3[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            
            table ( odds.s6.1sw > odds.s6.2sw ) #
            table ( odds.s6.1sw > odds.s6.3sw ) #
            table ( odds.s6.3sw > odds.s6.2sw ) #
            
            table ( odds.v3.1sw > odds.v3.2sw ) #
            table ( odds.v3.1sw > odds.v3.3sw ) #
            table ( odds.v3.3sw > odds.v3.2sw ) #
            
            sort ( odds.s6.3sw / odds.s6.2sw ) [c(2500,50000,97500)]
            
          ## six6 effect among sea ages
            table ( MVN [ , 17 ] >  MVN [ , 18 ] )
            table ( MVN [ , 17 ] >  MVN [ , 19 ] )
            table ( MVN [ , 18 ] >  MVN [ , 19 ] )
            
            table ( MVN [ , 20 ] >  MVN [ , 21 ] )
            table ( MVN [ , 21 ] >  MVN [ , 22 ] )
            table ( MVN [ , 20 ] >  MVN [ , 22 ] )
            
            ## coffiecnet for resL and six6 is negatively correlated
            cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
            cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
            cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
            
            ## MEANS
            
            XX= seq ( -1.6 , 1.6 , by = 0.05)
            
            i=1
            
            colnames(MVN)[1:12]
            
            ## residual length effect
            length.1SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 1 ] +  MVN [  , 4 ] * XX[i] + MVN [  , 7 ] * s6.val [2] + MVN [  , 10 ]* v3.val [2] ) })
            length.2SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 2 ] +  MVN [  , 5 ] * XX[i] + MVN [  , 8 ] * s6.val [2] + MVN [  , 11 ]* v3.val [2] ) })
            length.3SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 3 ] +  MVN [  , 6 ] * XX[i] + MVN [  , 9 ] * s6.val [2] + MVN [  , 12 ]* v3.val [2] ) })
            
            length.1SW.totW = exp ( length.1SW.totW.pre ) / ( 1 + exp ( length.1SW.totW.pre ) )
            length.2SW.totW = exp ( length.2SW.totW.pre ) / ( 1 + exp ( length.2SW.totW.pre ) )
            length.3SW.totW = exp ( length.3SW.totW.pre ) / ( 1 + exp ( length.3SW.totW.pre ) )
            
            ## median
            length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )
            
            ## 95 upper
            length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
            
            ## 95 lower
            length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )

          }
          ## herring probablaities 
          
          ## haddock figures six6 and vgll3 only
          {        
            
            
            vcov ( wm.PA.had.s6v3.A$gam)
            coef ( wm.PA.had.s6v3.A$gam)
            
            
            AAA = vcov ( wm.PA.had.s6v3.A$gam)## list [[2]] is the zero inlation model
            BBB = coef ( wm.PA.had.s6v3.A$gam) ## ngetaive infromt to make it look like binomial, not ZERO INFLATION!
            
            library(MASS)
            #AA1  =model.matrix (ss.PA1.six6.m1$gam)
            
            ## parametric permutations
            MOD1.vcov = AAA
            MOD1.coef = BBB
            MVN = mvrnorm (100000, mu=MOD1.coef, Sigma = MOD1.vcov )
            
            per1a = model.matrix(wm.PA.had.s6v3.A$gam)
            per1b = per1a [per1a[,1]==1,]
            per1c = per1b  [ sample ( 1:nrow(per1b) , 100000 , rep=T ) , ]
            
            per2a = model.matrix(wm.PA.had.s6v3.A$gam)
            per2b = per2a [per2a[,2]==1,]
            per2c = per2b  [ sample ( 1:nrow(per2b) , 100000 , rep=T ) , ]
            
            per3a = model.matrix(wm.PA.had.s6v3.A$gam)
            per3b = per3a [per3a[,3]==1,]
            per3c = per3b  [ sample ( 1:nrow(per3b) , 100000 , rep=T ) , ]
            
            ### "sea age, average food weight relation" 
            
            head(MVN)
            
            ### "sea age, average food weight relation" 
            par ( mfrow = c ( 1 , 4 ) )
            
            sw.food1 = cbind ( MVN [ , 1] + MVN [ , 7] * s6.val [2] + MVN [ , 10] * v3.val [2], 
                               MVN [ , 2] + MVN [ , 8] * s6.val [2] + MVN [ , 11] * v3.val [2] , 
                               MVN [ , 3] + MVN [ , 9] * s6.val [2] + MVN [ , 12] * v3.val [2] )
            
            
            prob.full.per.sea.age      = exp ( sw.food1[,] ) / (1 + exp (sw.food1[,]) )
            med.prob.full.per.sea.age  =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[50000] } ) )
            CI025.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[2500] } ) )
            CI975.prob.full.per.sea.age =  (apply ( prob.full.per.sea.age  , 2 , function(x) { sort(x)[97500] } ) )
            
            plot(1, type="n", xlim=c(0.7,3.3), ylim=c(0 , 0.15),  main = "probablity of haddock in the stomach per sea age" , xlab = "sea age" , 
                 ylab = "probablity of haddock in the stomach" ,  xaxt = "n")
            
            axis ( 1 , at = 1:3 ,  c("1SW","2SW","3SW")  )
            
            points( x = 1:3 , y = med.prob.full.per.sea.age , cex = 2, pch = 20, col=c("light green","orange","light blue") ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.prob.full.per.sea.age[i]  , CI975.prob.full.per.sea.age[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            legend ( x = 1, y=1, lwd =3 , col = c("light green", "orange" , "light blue") , pch=20, legend = c("1SW","2SW","3SW") , bty = "n" , cex=1.7)
            
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,2] ) ## p < 0.001
            table ( prob.full.per.sea.age[,1] > prob.full.per.sea.age[,3] ) # p < 0.001
            table ( prob.full.per.sea.age[,2] > prob.full.per.sea.age[,3] ) # p = 0.001
            
            ## odss in increase between LL and EE  in six6
            colnames(MVN)[7:9]
            ee.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [1]  , MVN [ , 8 ] * s6.val [1]  , MVN [ , 9 ] * s6.val [1] )
            ll.six6.food1 = cbind ( MVN [ , 7 ] * s6.val [2]  , MVN [ , 8 ] * s6.val [2]  , MVN [ , 9 ] * s6.val [2] )
            
            odds.s6.1sw = ( exp (ll.six6.food1[,1] ) / exp (ee.six6.food1[,1] ) )
            odds.s6.2sw = ( exp (ll.six6.food1[,2] ) / exp (ee.six6.food1[,2] ) )
            odds.s6.3sw = ( exp (ll.six6.food1[,3] ) / exp (ee.six6.food1[,3] ) )
            
            odds.s6.1sw.range = sort ( odds.s6.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.2sw.range = sort ( odds.s6.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.s6.3sw.range = sort ( odds.s6.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range) [ 2 , ]
            CI025.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 1 , ]
            CI975.weight.per.six6 = cbind(odds.s6.1sw.range,odds.s6.2sw.range,odds.s6.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 5),  main = "Odds of haddock in the stomach by six6 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of haddock in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light gray" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.six6 , cex = 2, pch = 20, col= c("light green","orange","light blue")  ) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.six6[i]  , CI975.weight.per.six6[i]  ) , lwd=3, col=c("light green","orange","light blue")[i]) }
            
            
            ## odss in increase between LL and EE  in vgll3
            colnames(MVN)[10:12]
            ee.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [1]  , MVN [ , 11 ] * v3.val [1]  , MVN [ , 12 ] * v3.val [1] )
            ll.vgll3.food1 = cbind ( MVN [ , 10 ] * v3.val [2]  , MVN [ , 11 ] * v3.val [2]  , MVN [ , 12 ] * v3.val [2] )
            
            odds.v3.1sw = ( exp (ll.vgll3.food1[,1] ) / exp (ee.vgll3.food1[,1] ) )
            odds.v3.2sw = ( exp (ll.vgll3.food1[,2] ) / exp (ee.vgll3.food1[,2] ) )
            odds.v3.3sw = ( exp (ll.vgll3.food1[,3] ) / exp (ee.vgll3.food1[,3] ) )
            
            odds.v3.1sw.range = sort ( odds.v3.1sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.2sw.range = sort ( odds.v3.2sw ) [ c ( 2500 , 50000 , 97500) ]
            odds.v3.3sw.range = sort ( odds.v3.3sw ) [ c ( 2500 , 50000 , 97500) ]
            
            med.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range) [ 2 , ]
            CI025.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 1 , ]
            CI975.weight.per.vgll3 = cbind(odds.v3.1sw.range,odds.v3.2sw.range,odds.v3.3sw.range)[ 3 , ]
            
            
            plot ( 1, type="n", xlim=c(0.5,3.5), ylim=c(0 , 5),  main = "Odds of haddock in the stomach by vgll3 allelic substitution" , 
                   xlab = "Sea age" , ylab = "Odds of haddock in the stomach" , xaxt = "n")
            abline( h=1, lty=2, col = "light green" , lwd=2)
            axis ( 1, at = c(1:3), labels = c ("1SW", "2SW" , "3SW" ) )
            
            points( x = 1:3 , y = med.weight.per.vgll3 , cex = 2, pch = 20, col=c("light green","orange","light blue")) 
            for ( i in 1:3) { lines ( x = c(i,i) , y = c (CI025.weight.per.vgll3[i]  , CI975.weight.per.vgll3[i]  ) , lwd=3, col=c("light green","orange","light blue")[i] ) }
            
            
            table ( odds.s6.1sw > odds.s6.2sw ) # 
            table ( odds.s6.1sw > odds.s6.3sw ) # 
            table ( odds.s6.3sw > odds.s6.2sw ) # 
            
            table ( odds.v3.1sw > odds.v3.2sw ) # 
            table ( odds.v3.1sw > odds.v3.3sw ) # 
            table ( odds.v3.3sw > odds.v3.2sw ) # 
            

            ## six6 effect among sea ages
            table ( MVN [ , 17 ] >  MVN [ , 18 ] ) ##
            table ( MVN [ , 17 ] >  MVN [ , 19 ] ) ##
            table ( MVN [ , 18 ] >  MVN [ , 19 ] ) ##
            
            table ( MVN [ , 20 ] >  MVN [ , 21 ] ) ##
            table ( MVN [ , 21 ] >  MVN [ , 22 ] ) ##
            table ( MVN [ , 20 ] >  MVN [ , 22 ] ) ##
            
            ## coffiecnet for resL and six6 is negatively correlated
            cor.test ( MVN [ , 14 ] , MVN [ , 17 ] )
            cor.test ( MVN [ , 15 ] , MVN [ , 18 ] )
            cor.test ( MVN [ , 16 ] , MVN [ , 19 ] )
            
            ## MEANS
            
            XX= seq ( -1.6 , 1.6 , by = 0.05)
            
            i=1
            
            colnames(MVN)[1:12]
            
            ## residual length effect
            length.1SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 1 ] +  MVN [  , 4 ] * XX[i] + MVN [  , 7 ] * s6.val [2] + MVN [  , 10 ]* v3.val [2] ) })
            length.2SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 2 ] +  MVN [  , 5 ] * XX[i] + MVN [  , 8 ] * s6.val [2] + MVN [  , 11 ]* v3.val [2] ) })
            length.3SW.totW.pre = sapply ( 1: length(XX) , function(i) {  ( MVN [  , 3 ] +  MVN [  , 6 ] * XX[i] + MVN [  , 9 ] * s6.val [2] + MVN [  , 12 ]* v3.val [2] ) })
            
            length.1SW.totW = exp ( length.1SW.totW.pre ) / ( 1 + exp ( length.1SW.totW.pre ) )
            length.2SW.totW = exp ( length.2SW.totW.pre ) / ( 1 + exp ( length.2SW.totW.pre ) )
            length.3SW.totW = exp ( length.3SW.totW.pre ) / ( 1 + exp ( length.3SW.totW.pre ) )
            
            ## median
            length.1SW.totW_med = apply (length.1SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.2SW.totW_med = apply (length.2SW.totW , 2, function(x) { sort(x)[50000] }  )
            length.3SW.totW_med = apply (length.3SW.totW , 2, function(x) { sort(x)[50000] }  )
            
            ## 95 upper
            length.1SW.totW_upp2 = apply (length.1SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.2SW.totW_upp2 = apply (length.2SW.totW , 2, function(x) { sort(x)[2500] }  )
            length.3SW.totW_upp2 = apply (length.3SW.totW , 2, function(x) { sort(x)[2500] }  )
            
            ## 95 lower
            length.1SW.totW_low2 = apply (length.1SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.2SW.totW_low2 = apply (length.2SW.totW , 2, function(x) { sort(x)[97500] }  )
            length.3SW.totW_low2 = apply (length.3SW.totW , 2, function(x) { sort(x)[97500] }  )
            
          }
          ## haddock probablaities 
          
          
          
          }
  ## prey species weight proprtion  

  ## COMPARING MODEL FIT WITH OTHER LOCUS (prey species proportion, supp. figure 7)
  {
    
                  SC.genoNUM2_BOK =  SC.genoNUM2 [ (SC.PHEN3$SCW.tot.ex) != 0 ,  ]
                  Dind.prey.AIC.TESTS.06Aug19 = list ( dTEST3_eel_v , dTEST3_eel_s , dTEST3_cap_v , dTEST3_cap_s , dTEST3_her_v , dTEST3_her_s , dTEST3_had_v , dTEST3_had_s )
                 ## these are p-values
                 
                 d.p.TEST3_eel_v =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova ( gamm ( SCW.eel.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) 
                            +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_eel_s =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova (  gamm ( SCW.eel.PR ~ 0 + Sea.ageF / ( resL2 + scale (vgll3.imp) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_cap_v =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova (  gamm ( SCW.cap.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_cap_s =  sapply (  c(1:174) , function (i) { print(i) 
                   AIC.T = tryCatch ( anova (  gamm ( SCW.cap.PR ~ 0 + Sea.ageF / ( resL2 + scale (vgll3.imp) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_her_v =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova (  gamm ( SCW.her.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_her_s =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova (  gamm ( SCW.her.PR ~ 0 + Sea.ageF / ( resL2 + scale (vgll3.imp) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_had_v =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova (  gamm ( SCW.had.PR ~ 0 + Sea.ageF / ( resL2 + scale (six6) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 d.p.TEST3_had_s =  sapply (  c(1:174) , function (i) { print(i) 
                   
                   AIC.T = tryCatch ( anova (  gamm ( SCW.had.PR ~ 0 + Sea.ageF / ( resL2 + scale (vgll3.imp) + scale (SC.genoNUM2_BOK [ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , i ])    ) +  s ( scale(DAY) ) + s( scale(long) ) + s(popF , bs= "re" )  , family = binomial , data=SC.PHEN_bok[ which ( !is.na(SC.genoNUM2_BOK[,i]) ) , ]  )$gam)$pTerms.table ,error=function(e) NA) 
                   c ( AIC.T  )
                 })
                 
                 mlogP_eel_s = ( -log ( unlist ( lapply ( d.p.TEST3_eel_s , function(x) x[12] ) ) ) )
                 mlogP_cap_s = ( -log ( unlist ( lapply ( d.p.TEST3_cap_s , function(x) x[12] ) ) ) )
                 mlogP_her_s = ( -log ( unlist ( lapply ( d.p.TEST3_her_s , function(x) x[12] ) ) ) )
                 mlogP_had_s = ( -log ( unlist ( lapply ( d.p.TEST3_had_s , function(x) x[12] ) ) ) )
                 mlogP_eel_v = ( -log ( unlist ( lapply ( d.p.TEST3_eel_v , function(x) x[12] ) ) ) )
                 mlogP_cap_v = ( -log ( unlist ( lapply ( d.p.TEST3_cap_v , function(x) x[12] ) ) ) )
                 mlogP_her_v = ( -log ( unlist ( lapply ( d.p.TEST3_her_v , function(x) x[12] ) ) ) )
                 mlogP_had_v = ( -log ( unlist ( lapply ( d.p.TEST3_had_v , function(x) x[12] ) ) ) )
  
                 par (mfrow = c (2,4) )             
                 hist(mlogP_eel_s) ; abline ( v = mlogP_eel_s [4] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_eel_s [4] < mlogP_eel_s [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_eel_s [4] < mlogP_eel_s [4:174] )) ) ) )
                 hist(mlogP_cap_s) ; abline ( v = mlogP_cap_s [4] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_cap_s [4] < mlogP_cap_s [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_cap_s [4] < mlogP_cap_s [4:174] )) ) ) )
                 hist(mlogP_her_s) ; abline ( v = mlogP_her_s [4] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_her_s [4] < mlogP_her_s [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_her_s [4] < mlogP_her_s [4:174] )) ) ) )
                 hist(mlogP_had_s) ; abline ( v = mlogP_had_s [4] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_had_s [4] < mlogP_had_s [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_had_s [4] < mlogP_had_s [4:174] )) ) ) )
                 hist(mlogP_eel_v) ; abline ( v = mlogP_eel_v [5] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_eel_v [5] < mlogP_eel_v [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_eel_v [5] < mlogP_eel_v [4:174] )) ) ))
                 hist(mlogP_cap_v) ; abline ( v = mlogP_cap_v [5] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_cap_v [5] < mlogP_cap_v [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_cap_v [5] < mlogP_cap_v [4:174] )) ) ))
                 hist(mlogP_her_v) ; abline ( v = mlogP_her_v [5] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_her_v [5] < mlogP_her_v [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_her_v [5] < mlogP_her_v [4:174] )) ) ))
                 hist(mlogP_had_v) ; abline ( v = mlogP_had_v [5] , col="red" ) ; text ( y=60 , x=1 ,  paste ( collapse = "" , c ( sum(mlogP_had_v [5] < mlogP_had_v [4:174] , na.rm=T) , "out of" , sum(!is.na(mlogP_had_v [5] < mlogP_had_v [4:174] )) ) ))
  

    }    
  ## COMPARING MODEL FIT WITH OTHER LOCUS  

  ## PVALUES COMPARING MODEL FIT WITH OTHER LOCUS (total stomach weight, supp. figure 7)
  {
    TEST1P = sapply ( c (1:174) , function (i) { print(i)
      
      MOD.N = tryCatch (  (glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6)   ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                      scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3 [ which ( !is.na(SC.genoNUM2[,i]) ) , ], family= truncated_nbinom2 , 
                                    control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) ) ) ,error=function(e) NA) 
      
      MOD.T = tryCatch (  ( glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (six6) + SC.genoNUM2[which ( !is.na(SC.genoNUM2[,i]) ),i] ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                       scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3 [ which ( !is.na(SC.genoNUM2[,i]) ) , ] , family= truncated_nbinom2 , 
                                     control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) ) )   , error=function(e) NA) 
      
      tryCatch ( anova ( MOD.N , MOD.T  ) , error=function(e) NA)
      
    } ) # vgll3.imp test
    TEST2P = sapply ( c(1:174) , function (i) { print(i)
      
      MOD.N = tryCatch (  ( glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (vgll3.imp)   ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                       scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3 [ which ( !is.na(SC.genoNUM2[,i]) ) , ], family= truncated_nbinom2 , 
                                     control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) ) ) ,error=function(e) NA ) 
      
      MOD.T = tryCatch (  ( glmmTMB (SCW.totBINS ~ 0 + Sea.ageF / ( scale (resL2) + scale (vgll3.imp) + SC.genoNUM2[which ( !is.na(SC.genoNUM2[,i]) ),i] ) + scale ( sDays1 ) + scale ( sDays2 ) + scale ( sDays3) + scale ( sDays4) + scale ( sDays5) + 
                                       scale ( sLong1) + scale ( sLong2) + scale ( sLong3) + scale (  sLong4) + scale ( sLong5) + ( 1 |popF), ziformula = ~ . , data = SC.PHEN3 [ which ( !is.na(SC.genoNUM2[,i]) ) , ], family= truncated_nbinom2 , 
                                     control = glmmTMBControl(optCtrl = list(iter.max = 100000, eval.max = 100000), profile = T, collect = FALSE) ) ) ,error=function(e) NA) 
      
      
      tryCatch ( anova ( MOD.N , MOD.T  ) , error=function(e) NA)
      
    } ) # six6 test 
    
    #six6test
    T1logP = sapply (1:174, function(i) { tryCatch (  -log(TEST1P[[i]][2,8])  , error=function(e) NA)  }) # vgll3
    T2logP = sapply (1:174, function(i) { tryCatch (  -log(TEST2P[[i]][2,8])  , error=function(e) NA)  }) # six6
    
    plot(T1logP)
    plot(T2logP)

    T2logP_SIX6 = T2logP [ -c(1:3,174) ]  # small number -> better fit
    T1logP_VGLL3 = T1logP [ -c(1:3,174) ]  # small number -> better fit
    
    head(T2logP_SIX6)
    head(T1logP_VGLL3)
    
    par ( mfrow = c ( 1 , 2 ) )
    hist ( T2logP_SIX6 , xlab = "-log(Pnull-genetic)" )
    abline ( v = T2logP_SIX6[1] , col="red" )
    
    hist ( T1logP_VGLL3 , xlab = "deltaAIC(null-genetic)" )
    abline ( v = T1logP_VGLL3[2] , col="red" )
    
    rank_fit = cbind ( colnames(SC.genoNUM2)[-c(1:3,174:175)] , T2logP_SIX6 , T1logP_VGLL3 )
    which ( order ( -as.numeric(rank_fit[ !is.na(rank_fit[,2]) , 2 ]) , decreasing = F ) == 1 ) ## six6 order
    which ( order ( -as.numeric(rank_fit[ !is.na(rank_fit[,3]) , 3 ]) , decreasing = F ) == 1 ) ## vgll3 order
    
  }
  ## PVALUES ENDS
  
  

